@@ -23,7 +23,7 @@ class History(object):
             "Authorization": "token {token}".format(token=self._token),
             "X-API-Version": "20151130",
             "Accept": "application/json",
-            "User-Agent": "Python API 1.90 / {local_version}".format(local_version=platform.python_version())
+            "User-Agent": "Python API 1.92 / {local_version}".format(local_version=platform.python_version())
         }
 
         self._dataset_id = None
@@ -100,7 +100,7 @@ class History(object):
         )
         return json.loads(response.text)
 
-    def get_presigned_url(self, dataset_id, history_date):
+    def get_url(self, dataset_id, history_date):
         if not dataset_id:
             raise Exception('Invalid dataset_id')
 
